@@ -9,7 +9,7 @@ import pymex
 
 class RecordBuilder():
 
-    def __init__(self,debug=False):
+    def __init__(self,cvpath, debug=False):
         self.debug = debug
         self.oboUrl = 'https://www.ebi.ac.uk/ols/api/ontologies/%CVT%/terms?iri=http://purl.obolibrary.org/obo/'
         self.taxUrl = 'https://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=taxonomy&retmode=xml&id='
@@ -17,6 +17,18 @@ class RecordBuilder():
         self.uniUrl = 'https://www.uniprot.org/uniprot/'
         self.cvreg = re.compile("([^:]+:\d+)(\(.+\))?")
         self.cvtrec = {}
+        self.cdpthDict = { "IMEx":[{ "value": "imex curation",
+                                     "name": "curation depth",
+                                     "nameAc": "MI:0955" },
+                                   { "name": "imex curation",
+                                     "nameAc": "MI:0959"
+                                   }],
+                           "MIMIx":[ { "value": "mimix curation",
+                                       "name": "curation depth",
+                                       "nameAc": "MI:0955" },
+                                     { "name": "mimix curation",
+                                       "nameAc": "MI:0960"
+                                     }] }
         self.taxrec = {}
         self.unirec = {}
         self.ebirec = {}
@@ -32,11 +44,15 @@ class RecordBuilder():
         srcpath = os.path.join( self.pdir,'jmif-source.jmif' )
         self.template["source"] = json.load( open( srcpath, 'r' ) )["source"]
 
-        cvtpath = os.path.join( self.pdir,'jmif-cvterm.jmif' )
+        if len(cvpath) == 0:
+            cvtpath = os.path.join( self.pdir,'jmif-cvterm.jmif' )
+        else:
+            cvtpath = cvpath
+            
         self.cvdict = json.load( open( cvtpath, 'r' ) )
 
     def cvterm( self, cvid ):
-        
+        icvid = cvid
         cvmatch = self.cvreg.match( cvid )
         if cvmatch:
             cvid = cvmatch.group(1)
@@ -52,41 +68,57 @@ class RecordBuilder():
         if cvlabel is not None:
             term = {"label" : cvlabel }
             return term
-        
-        if cvid not in self.cvtrec:
+        #print(cvid)
+        #print("---")
+        if isinstance(cvid, str):
+            if cvid not in self.cvtrec:
+                #print("s")
+                #fetch term from OLS
 
-            #fetch term from OLS
-
-            cvc = cvid.split(":")
+                cvc = cvid.split(":")
             
-            cvurl = self.oboUrl.replace("%CVT%",cvc[0].lower()) + cvid.replace(':','_')            
-            jcv = json.load( urlopen( cvurl ) )
+                cvurl = self.oboUrl.replace("%CVT%",cvc[0].lower()) + cvid.replace(':','_')            
+                jcv = json.load( urlopen( cvurl ) )
             
-            term = {}
-            term['label'] = jcv['_embedded']['terms'][0]['label']
+                term = {}
+                term['label'] = jcv['_embedded']['terms'][0]['label']
             
-            if "description" in jcv['_embedded']['terms'][0]:
-                 term['def'] = jcv['_embedded']['terms'][0]["description"]
+                if "description" in jcv['_embedded']['terms'][0]:
+                    term['def'] = jcv['_embedded']['terms'][0]["description"]
                  
-            elif "definition" in jcv['_embedded']['terms'][0]['annotation']:
-                term['def'] = jcv['_embedded']['terms'][0]['annotation']['definition'][0]
+                elif "definition" in jcv['_embedded']['terms'][0]['annotation']:
+                    term['def'] = jcv['_embedded']['terms'][0]['annotation']['definition'][0]
                 
-            term['id'] = jcv['_embedded']['terms'][0]['obo_id']
+                term['id'] = jcv['_embedded']['terms'][0]['obo_id']
 
-            try:
-                term["dbac"]=self.cvdict[cvc[0].lower()]["dbac"]
-                term["db"]=self.cvdict[cvc[0].lower()]["db"]
-            except:
-                term["dbac"]=None
-                term["db"]=None
-            self.cvtrec[ term['id'] ] = term 
-        
+                try:
+                    term["dbac"]=self.cvdict[cvc[0].lower()]["dbac"]
+                    term["db"]=self.cvdict[cvc[0].lower()]["db"]
+                except:
+                    term["dbac"]=None
+                    term["db"]=None
+                self.cvtrec[ term['id'] ] = term 
+                
+        if isinstance(cvid, dict):
+            if icvid not in self.cvtrec:            
+                term = {}
+                term["id"]=cvid['id']
+                term["db"]=cvid['db']
+                term["dbac"]=cvid['dbac']                
+                term["label"]=icvid
+                self.cvtrec[ icvid ] = term 
+
+                #<primaryRef db="cabri" dbAc="MI:0246" id="ICLC HTL04001" refType="identity" refTypeAc="MI:0356"/>
+
+                
+            return self.cvtrec[icvid]
+                
         return self.cvtrec[cvid]
 
     def buildCvTerm( self, cvid ):
         
         term = self.cvterm( cvid )
-
+        
         res = { "names": { "shortLabel": term["label"] } }
 
         if "id" in term:
@@ -156,7 +188,7 @@ class RecordBuilder():
             accpath = "/up:uniprot/up:entry/up:accession/text()"
             verpath = "/up:uniprot/up:entry/@version"
             snamepath = "/up:uniprot/up:entry/up:name/text()"
-            lnamepath = "/up:uniprot/up:entry/up:protein/up:recommendedName/up:fullName/text()"
+            lnamepath = "/up:uniprot/up:entry/up:protein/*/up:fullName/text()"
             taxpath = "/up:uniprot/up:entry/up:organism/up:dbReference[./@type='NCBI Taxonomy']/@id"
             record = etree.parse( urlopen( uniurl ) )
         
@@ -207,6 +239,8 @@ class RecordBuilder():
         
         record = {}
         source = None
+        econt = None
+        cdpth = None
         interaction = None
         interactor = None
         participant = None
@@ -215,6 +249,7 @@ class RecordBuilder():
         xtgt = None
         seqtgt = None
         bibref = None
+        
 
         with open( filename, 'r' ) as sf:
             for ln in sf:
@@ -230,11 +265,27 @@ class RecordBuilder():
                         record["source"] =  self.template["source"][src]
                     xtgt = record["source"]
 
+                elif ln.startswith("email"):
+                    econt = col[1]
+                    
+                elif ln.startswith("depth"):
+                    cdpth = col[1]
+                    if cdpth in self.cdpthDict:
+                        cdpth = self.cdpthDict[cdpth]
+                    else:
+                        cdpth = None
+                        
                 elif ln.startswith("pmid"):
                     pmid = col[1]
                     pref = self.buildXref( pmid, db="pubmed", dbAc="MI:0446",
                                            refType="primary-reference", refTypeAc="MI:0358" )    
                     bibref = {"xref":{"primaryRef": pref}}
+
+                elif ln.startswith("doi"):
+                    pmid = col[1]
+                    pref = self.buildXref( pmid, db="doi", dbAc="MI:0574",
+                                           refType="primary-reference", refTypeAc="MI:0358" )    
+                    bibref = {"xref":{"primaryRef": pref}}
                     
                 elif ln.startswith("interaction"):
                     self.feature = False
@@ -265,7 +316,7 @@ class RecordBuilder():
                             "shortLabel": ctax["sname"],
                             "fullName": ctax["lname"] },
                         "ncbiTaxId": ctax["taxid"] } )
-                    
+                   
                     if len(col) > 4:
                         ctype = self.buildCvTerm( col[4] )
                         if ctype is not None:
@@ -281,7 +332,21 @@ class RecordBuilder():
                         if tissue is not None:
                             interaction["experiment"][0]["hostOrganism"][0]["tissue"] = tissue
                         
-                    xtgt = interaction    
+                    xtgt = interaction
+
+                    if econt is not None or cdpth is not None:
+                        interaction["experiment"][0]["attribute"] = []
+
+                        if econt is not None:                        
+                            interaction["experiment"][0]["attribute"].append(
+                                { "name":"contact-email",
+                                  "nameAc":"MI:0634",
+                                  "value":econt } )
+
+                        if cdpth is not None:
+                            for a in cdpth:
+                                interaction["experiment"][0]["attribute"].append(a)
+                                                    
                 elif ln.startswith("molecule"):
                     self.feature = False
                     participant = {}
@@ -385,7 +450,7 @@ class RecordBuilder():
                 elif ln.startswith("expprep"):                    
                     self.feature = False            
                     participant.setdefault("experimentalPreparation",[])                    
-                    for prep in col[1:]:                                                
+                    for prep in col[1:]:                        
                         participant["experimentalPreparation"].append( self.buildCvTerm( prep ) )                    
                 elif ln.startswith("biorole"):
                     self.feature = False            
